@@ -3,7 +3,7 @@ import { ErrorDetails } from 'app/api/clients/provisioning/v0alpha1';
 import { WizardFormData } from '../Wizard/types';
 
 export type RepositoryField = keyof WizardFormData['repository'];
-export type RepositoryFormPath = `repository.${RepositoryField}`;
+export type RepositoryFormPath = `repository.${RepositoryField}` | `repository.sync.intervalSeconds`;
 export type FormErrorTuple = [RepositoryFormPath | null, { message: string } | null];
 
 /**
@@ -13,7 +13,25 @@ export type FormErrorTuple = [RepositoryFormPath | null, { message: string } | n
  * @returns Tuple with form field path and error message
  */
 export const getFormErrors = (errors: ErrorDetails[]): FormErrorTuple => {
-  const fieldsToValidate = ['local.path', 'github.branch', 'github.url', 'github.token'];
+  const fieldsToValidate = [
+    'local.path',
+    'github.branch',
+    'github.url',
+    'github.path',
+    'secure.token',
+    'gitlab.branch',
+    'gitlab.url',
+    'bitbucket.branch',
+    'bitbucket.url',
+    'git.branch',
+    'git.url',
+    'sync.intervalSeconds',
+  ];
+
+  const nestedFieldMap: Record<string, RepositoryFormPath> = {
+    'sync.intervalSeconds': 'repository.sync.intervalSeconds',
+  };
+
   const fieldMap: Record<string, RepositoryFormPath> = {
     path: 'repository.path',
     branch: 'repository.branch',
@@ -25,6 +43,12 @@ export const getFormErrors = (errors: ErrorDetails[]): FormErrorTuple => {
     if (error.field) {
       const cleanField = error.field.replace('spec.', '');
       if (fieldsToValidate.includes(cleanField)) {
+        // Check for direct nested field mapping first
+        if (cleanField in nestedFieldMap) {
+          return [nestedFieldMap[cleanField], { message: error.detail || `Invalid ${cleanField}` }];
+        }
+
+        // Fall back to simple field mapping for non-nested fields
         const fieldParts = cleanField.split('.');
         const lastPart = fieldParts[fieldParts.length - 1];
 
